==> hbase-2.3.7-src.tar.gz: hbase-2.3.7/hbase-http/src/main/java/org/apache/hadoop/hbase/http/AdminAuthorizedFilter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.http;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.security.authorize.AccessControlList;
import org.apache.yetus.audience.InterfaceAudience;

@InterfaceAudience.Private
public class AdminAuthorizedFilter implements Filter {

  private Configuration conf;
  private AccessControlList adminsAcl;

  @Override public void init(FilterConfig filterConfig) throws ServletException {
    adminsAcl = (AccessControlList) filterConfig.getServletContext().getAttribute(
        HttpServer.ADMINS_ACL);
    conf = (Configuration) filterConfig.getServletContext().getAttribute(
        HttpServer.CONF_CONTEXT_ATTRIBUTE);
  }

  @Override
  public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
      throws IOException, ServletException {
    if (!(request instanceof HttpServletRequest) || !(response instanceof HttpServletResponse)) {
      throw new UnsupportedOperationException("Only accepts HTTP");
    }
    HttpServletRequest httpReq = (HttpServletRequest) request;
    HttpServletResponse httpResp = (HttpServletResponse) response;

    if (!HttpServer.hasAdministratorAccess(conf, adminsAcl, httpReq, httpResp)) {
      return;
    }

    chain.doFilter(request, response);
  }

  @Override public void destroy() {}
}

==> hbase-2.6.3-src.tar.gz: hbase-2.6.3/hbase-http/src/main/java/org/apache/hadoop/hbase/http/AdminAuthorizedFilter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.http;

import java.io.IOException;
import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.security.authorize.AccessControlList;
import org.apache.yetus.audience.InterfaceAudience;

@InterfaceAudience.Private
public class AdminAuthorizedFilter implements Filter {

  private Configuration conf;
  private AccessControlList adminsAcl;

  @Override
  public void init(FilterConfig filterConfig) throws ServletException {
    adminsAcl =
      (AccessControlList) filterConfig.getServletContext().getAttribute(HttpServer.ADMINS_ACL);
    conf = (Configuration) filterConfig.getServletContext()
      .getAttribute(HttpServer.CONF_CONTEXT_ATTRIBUTE);
  }

  @Override
  public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
    throws IOException, ServletException {
    if (!(request instanceof HttpServletRequest) || !(response instanceof HttpServletResponse)) {
      throw new UnsupportedOperationException("Only accepts HTTP");
    }
    HttpServletRequest httpReq = (HttpServletRequest) request;
    HttpServletResponse httpResp = (HttpServletResponse) response;

    if (!HttpServer.hasAdministratorAccess(conf, adminsAcl, httpReq, httpResp)) {
      return;
    }

    chain.doFilter(request, response);
  }

  @Override
  public void destroy() {
  }
}
